@@ -105,7 +105,6 @@ const FS_SRC: &str = r#"
     }
 "#;
 
-
 /// Peforms egui's painting in the GlutWindow
 pub struct Painter {
     vertex_array: GLuint,
@@ -517,8 +516,9 @@ impl Painter {
                 }
             }
 
-            gl::Disable(gl::SCISSOR_TEST);
             gl::Disable(gl::FRAMEBUFFER_SRGB);
+            gl::Disable(gl::SCISSOR_TEST);
+            gl::Disable(gl::BLEND);
         }
     }
 
@@ -643,6 +643,10 @@ impl Painter {
                 gl::UNSIGNED_SHORT,
                 ptr::null(),
             );
+
+            gl::DisableVertexAttribArray(a_pos_loc);
+            gl::DisableVertexAttribArray(a_tc_loc);
+            gl::DisableVertexAttribArray(a_srgba_loc);
         }
     }
 
